@@ -119,7 +119,8 @@ SilentProfile=False
 DimmDisplay=False
 PreviousBrightness=5
 RecordingBrightness=0
-Previous_Profile_was_silent=False
+Previous_Profile_was_silent=False #for restoration at end of recording
+Previous_Profile_was_silent2=False #for restoration at end of music
 PreviousVolume=50
 
 gstream_player=""
