@@ -72,7 +72,12 @@ def LoadPresetNames():
             tmp=PresetNames.get('main', 'preset'+str(i+1))
             data.preset_names[i] = tmp.decode("utf-8")
         except:
-            data.preset_names[i]=str(_("Preset")+" "+str(i+1))
+#            name=_("Preset")
+#            name=unicode(name)
+#            name=name.decode("utf-8")
+##Todo: Get unicode problem working
+            name="Preset"
+            data.preset_names[i]=name+" "+str(i+1)
             PresetNames.set('main', 'preset'+str(i+1), data.preset_names[i])
 
 
@@ -97,13 +102,13 @@ def WritePresetNames():
     if (not os.path.exists(str(data.configFolder))):
         print "Create configuration folder: ", data.configFolder
         os.mkdir(data.configFolder)
-    try:
-        handle = open(f, 'w')
-        PresetNames.write(handle)
-        handle.close()
-        print "Preset names saved"
-    except:
-        print "Failed to write preset names file!"
+#    try:
+    handle = open(f, 'w')
+    PresetNames.write(handle)
+    handle.close()
+    print "Preset names saved"
+#    except:
+#        print "Failed to write preset names file!"
 
 
 
